module Hat.Data.Ix
  (Ix(grange,gindex,ginRange,grangeSize,srange,sindex,sinRange
      ,srangeSize)) where

import qualified Hat.PreludeBasic 
import qualified Prelude 
import Hat.Hack 
import qualified Hat.Hat as T 
import Hat.Hat  (WrapVal(wrapVal))
import Hat.Prelude 
import Hat.Ix 

tData_Ix = T.mkModule "Data.Ix" "Data/Ix.hs" Prelude.False
